@@ -52,7 +52,6 @@ def set_server(value: "DebugAdapterServer") -> None:
 
 @_logger.call
 def wait_for_server(timeout: float = 10) -> "DebugAdapterServer":
-
     start_time = time.monotonic()
     while get_server() is None and time.monotonic() - start_time < timeout:
         time.sleep(0.005)
@@ -75,13 +74,6 @@ async def _debug_adapter_server_async(
 ) -> None:
     from .server import DebugAdapterServer
 
-    hidden_tasks = os.environ.get("ROBOTCODE_DISABLE_HIDDEN_TASKS", "0")
-    hide = hidden_tasks == "0"
-
-    if hide:
-        current_thread = threading.current_thread
-        setattr(current_thread, "pydev_do_not_trace", True)
-
     async with DebugAdapterServer(
         mode=mode,
         tcp_params=TcpParams(addresses or "127.0.0.1", port),
@@ -93,7 +85,7 @@ async def _debug_adapter_server_async(
         await server.serve()
 
 
-def _debug_adapter_server_(
+def _debug_adapter_server(
     on_config_done_callback: Optional[Callable[["DebugAdapterServer"], None]],
     mode: ServerMode,
     addresses: Union[str, Sequence[str], None],
@@ -122,6 +114,12 @@ def start_debugpy(
     if port != debugpy_port:
         _logger.warning(lambda: f"start debugpy session on port {port}")
 
+    # this is set by vscode for non config debugpy sessions, we don't need it, so remove it
+    if "DEBUGPY_ADAPTER_ENDPOINTS" in os.environ:
+        del os.environ["DEBUGPY_ADAPTER_ENDPOINTS"]
+    if "VSCODE_DEBUGPY_ADAPTER_ENDPOINTS" in os.environ:
+        del os.environ["VSCODE_DEBUGPY_ADAPTER_ENDPOINTS"]
+
     if enable_debugpy(port, addresses):
         global config_done_callback
 
@@ -186,7 +184,7 @@ def run_debugger(
     app.verbose("Start robotcode debugger thread")
 
     run_as_debugpy_hidden_task(
-        _debug_adapter_server_,
+        _debug_adapter_server,
         config_done_callback,
         mode,
         addresses,
